@@ -1,8 +1,11 @@
 import logging
-from time import sleep
+import random
 from pyage.core.address import Addressable
 from pyage.core.inject import Inject
 
+
+logger = logging.getLogger(__name__)
+
 AGENT = "agent"
 
 class AbstractAgent:
@@ -16,7 +19,7 @@ class AbstractAgent:
         return max(genotype.fitness for genotype in self.population)
 
     def add_genotype(self, population):
-        print "received genotype: ", population
+        logger.debug("received genotype!")
         self.population.extend(population)
 
     @Inject("operators", "initializer")
@@ -31,7 +34,7 @@ class Agent(Addressable, AbstractAgent):
     def __init__(self, name=None):
         self.name = name
         super(Agent, self).__init__()
-        print "address:", self.address
+        logger.debug("address:" + self.address)
         self.population = []
         self.validate_operators()
         self.initialize()
@@ -39,19 +42,19 @@ class Agent(Addressable, AbstractAgent):
 
     def step(self):
         self.steps += 1
-        print self.steps, self.address, self.get_fitness()
+        logger.debug("%s %s %s",self.steps, self.address, self.get_fitness())
         for o in self.operators:
             o.process(self.population)
         self.__send_genotype()
         self.__migrate()
 
     def __send_genotype(self):
-        if self.steps % 10 == 0:
+        if random.random() < 0.01:
             try:
                 neighbour = self.locator.get_neighbour(self)
                 if neighbour:
-                    print "neighbour: ", neighbour.get_address(), self.population
-                    probe = list(self.population[::5])
+                    logger.debug("neighbour: %s", neighbour.get_address())
+                    probe = list(self.population.sort(key=lambda g:g.fitness))[:20:2]
                     neighbour.add_genotype(probe)
             except:
                 logging.exception('')
@@ -86,6 +89,10 @@ class AggregateAgent(Addressable, AbstractAgent):
     def get_agents(self):
         return self.__agents.values()
 
+    def get_fitness(self):
+        return max(agent.get_fitness() for agent in self.__agents.values())
+
+
 def agents_factory(*args):
     def factory():
         agents = {}
@@ -93,6 +100,7 @@ def agents_factory(*args):
             agent = Agent(name)
             agents[agent.get_address()] = agent
         return agents
+
     return factory
 
 
@@ -103,4 +111,5 @@ def aggregate_agents_factory(*args):
             agent = AggregateAgent(name)
             agents[agent.get_address()] = agent
         return agents
+
     return factory
