@@ -4,6 +4,9 @@ import Pyro4
 from pyage.core.agent import AGENT
 from pyage.core.inject import Inject
 
+logger = logging.getLogger(__name__)
+
+
 class Pyro4Locator(object):
     @Inject("ns_hostname")
     def __init__(self):
@@ -16,7 +19,7 @@ class Pyro4Locator(object):
     def get_neighbour(self, agent):
         try:
             random_agent = self.__get_random_agent(agent)
-            print random_agent.get_address()
+            logger.debug(random_agent.get_address())
             return  random_agent
         except:
             logging.exception('')
@@ -24,7 +27,7 @@ class Pyro4Locator(object):
     def __get_random_agent(self, a):
         ns = Pyro4.locateNS(self.ns_hostname)
         agents = ns.list(AGENT)
-        print agents
+        logger.debug(agents)
         del agents[AGENT + "." + a.address]
         return Pyro4.Proxy(random.choice(agents.values()))
 
@@ -33,5 +36,5 @@ class ParentLocator(object):
     def get_neighbour(self, agent):
         siblings = list(agent.parent.get_agents())
         siblings.remove(agent)
-        print siblings
+        logger.debug([s.get_address() for s in siblings])
         return random.choice(siblings)
\ No newline at end of file
